
package Bundle::Net::LDAP;

$VERSION = '0.02';

1;

__END__

=head1 NAME

Bundle::Net::LDAP - A bundle for Net::LDAP

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Net::LDAP'>

=head1 CONTENTS

Convert::ASN1

Digest::MD5

URI

URI::ldap

IO::Socket::SSL

XML::Parser

Net::LDAP

=head1 DESCRIPTION

This bundle all modules that Net::LDAP depends on.

=head1 AUTHOR

Graham Barr

=for html <hr>

I<$Id: //depot/ldap/lib/Bundle/Net/LDAP.pm#4 $>

=cut

